inbound

Function inbound 

pub fn inbound(
    config: InboundConfig,
    tx: UnboundedSender<ReplyBatch>,
    socket: Arc<Socket>,
)
Listen for incoming packets Creates two threads, one that listens on the socket and another that forwards results to the orchestrator and shuts down the receiving socket when appropriate. Makes sure that the received packets are valid and belong to the current measurement.

Arguments

  • config - configuration for the inbound worker thread
  • tx - sender to put task results in
  • socket - the socket to listen on

Panics

If the measurement type is invalid