InboundConfig

Struct InboundConfig 

pub struct InboundConfig {
    pub m_id: u32,
    pub worker_id: u16,
    pub p_type: ProtocolType,
    pub abort_s: Arc<AtomicBool>,
    pub is_traceroute: bool,
    pub origin_id: u32,
    pub sport: u16,
    pub src: String,
    pub is_transport_trace: bool,
}
Configuration for an inbound packet listening worker.

This struct holds all the parameters needed to initialize and run a worker that listens for and processes incoming measurement packets.

Fields

m_id: u32

The 16-bit measurement ID.

worker_id: u16

The unique ID of this specific worker.

p_type: ProtocolType

Protocol used

abort_s: Arc<AtomicBool>

A shared signal that can be used to gracefully shut down the worker.

is_traceroute: bool

Indicates if the measurement involves traceroute.

origin_id: u32

Origin ID associated with the Socket

sport: u16

Source port used

src: String

Source address used

is_transport_trace: bool

Identifies transport traceroute measurements, which require special handling